import { jsx as _jsx } from "react/jsx-runtime";
import { useLayoutEffect, useRef, useState } from 'react';
import * as monaco from 'monaco-editor';
const defaultStyle = {
    width: '100%',
    height: '100%',
};
const defaultOptions = {
    fontSize: 12,
};
export const JSONEditor = ({ id, onSave, onError, style, current, containerStyle, value = '', schema, }) => {
    const [code] = useState(value);
    const containerRef = useRef(null);
    const editor = useRef();
    const model = useRef();
    const subscription = useRef();
    useLayoutEffect(() => {
        initMonaco();
        return () => {
            destoryMonaco();
        };
    }, [schema, current]);
    const initMonaco = () => {
        monaco.languages.json.jsonDefaults.setDiagnosticsOptions({
            validate: true,
            schemas: [
                {
                    uri: `http://farrow/${id}-input.json`,
                    schema,
                },
            ],
        });
        const result = createEditor(id, containerRef.current, code, defaultOptions, model.current, onSave, onError);
        editor.current = result[0];
        model.current = result[1];
    };
    const destoryMonaco = () => {
        if (editor.current) {
            editor.current.dispose();
            const model = editor.current.getModel();
            if (model) {
                model.dispose();
            }
        }
        if (subscription.current) {
            subscription.current.dispose();
        }
    };
    style = Object.assign(Object.assign({}, defaultStyle), style);
    return (_jsx("div", Object.assign({ style: containerStyle }, { children: _jsx("div", { ref: containerRef, style: style }, void 0) }), void 0));
};
const createEditor = (id, container, value, options = {}, _model, onSave, onError) => {
    monaco.languages.json.jsonDefaults.setDiagnosticsOptions({
        validate: true,
        allowComments: true,
        schemaValidation: 'warning',
        schemaRequest: 'warning',
        trailingCommas: 'warning',
    });
    const modelUri = monaco.Uri.parse(`a://b/${id}-input.json`);
    const model = _model || monaco.editor.createModel(value, 'json', modelUri);
    const editor = monaco.editor.create(container, Object.assign(Object.assign({}, options), { value, language: 'json', model, minimap: {
            enabled: false,
        } }));
    model.onDidChangeContent(() => {
        onSave && onSave(model.getValue());
    });
    return [editor, model];
};
export default createEditor;
//# sourceMappingURL=JSONEditor.js.map