import { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { sessionActions } from './store/sessionsSlice';
import { getIntrospection } from './utils';
// Use throughout your app instead of plain `useDispatch` and `useSelector`
export const useAppDispatch = () => useDispatch();
export const useAppSelector = useSelector;
export const useSync = ({ id, servicePath }) => {
    const [loading, setLoading] = useState(false);
    const [error, setError] = useState(!servicePath ? 'Invalid Service URL' : null);
    const dispatch = useAppDispatch();
    const sync = () => {
        if (!servicePath) {
            setError('Invalid Service URL');
        }
        setError(null);
        setLoading(true);
        getIntrospection(servicePath)
            .then((result) => {
            if (result.isOk) {
                dispatch(sessionActions.updateSchema({ id, schema: result.value }));
            }
            else {
                setError('Server Error');
            }
        })
            .catch((err) => {
            setError('Unknown Error');
        })
            .finally(() => {
            setLoading(false);
        });
    };
    return {
        loading,
        error,
        sync,
    };
};
export const useInternal = (callback, intermittent) => {
    const [running, setRunning] = useState(false);
    const [intervalId, setIntervalId] = useState(0);
    const start = () => {
        setRunning(true);
        setIntervalId(setInterval(callback, intermittent));
    };
    const stop = () => {
        setRunning(false);
        clearInterval(intervalId);
    };
    useEffect(() => {
        return () => {
            stop();
        };
    }, []);
    return {
        running,
        start,
        stop,
    };
};
//# sourceMappingURL=hook.js.map