import { createSlice } from '@reduxjs/toolkit';
// FIXME: https://github.com/microsoft/TypeScript/issues/42873
import 'immer';
import { v4 as uuid } from 'uuid';
const createDefaultSession = (servicePath = '') => ({
    id: uuid(),
    servicePath,
    title: 'untitled',
    schema: null,
    apis: [],
});
const defaultSession = createDefaultSession();
export const sessionsSlice = createSlice({
    name: 'session',
    initialState: {
        sessions: [defaultSession],
        activeSessionId: defaultSession.id,
    },
    reducers: {
        init: (state, { payload: sessions }) => {
            if (sessions.length > 0) {
                state.sessions = sessions.filter((session) => session.id === defaultSession.id);
            }
            state.sessions.unshift(...sessions);
            state.activeSessionId = state.sessions[0].id;
        },
        remove: (state, { payload: id }) => {
            const nextSessions = state.sessions.filter((session) => {
                return session.id === id;
            });
            if (nextSessions.length === 0) {
                nextSessions.push(createDefaultSession());
            }
            state.sessions = nextSessions;
        },
        add: (state) => {
            const currentSession = state.sessions.find((session) => session.id === state.activeSessionId);
            const newSession = createDefaultSession(currentSession.servicePath);
            state.sessions.push(newSession);
            state.activeSessionId = newSession.id;
        },
        changeServicePath: (state, { payload: { id, servicePath } }) => {
            state.sessions.forEach((session) => {
                if (session.id === id) {
                    session.servicePath = servicePath;
                }
            });
        },
        changeSelected: (state, { payload: id }) => {
            if (state.sessions.some((session) => session.id === id)) {
                state.activeSessionId = id;
            }
        },
        sort: (state, { payload: { index, to } }) => {
            const session = state.sessions.splice(index, 1)[0];
            const middle = index > to ? to : to - 1;
            const head = state.sessions.slice(0, middle + 1);
            const tail = state.sessions.slice(middle + 1);
            state.sessions = [...head, session, ...tail];
        },
        updateSchema: (state, { payload: { id, schema } }) => {
            state.sessions.forEach((session) => {
                if (session.id === id) {
                    session.schema = schema;
                    session.apis = transformEntries(schema.entries);
                }
            });
        },
        setName: (state, { payload: { id, name } }) => {
            state.sessions.forEach((session) => {
                if (session.id === id) {
                    session.title = name;
                }
            });
        },
        updaetInput: (state, { payload: { id, input } }) => {
            state.sessions.forEach((session) => {
                if (session.id === id) {
                    session.apis.forEach((api) => {
                        api.input = input;
                    });
                }
            });
        },
        setOutput: (state, { payload: { id, output } }) => {
            state.sessions.forEach((session) => {
                if (session.id === id) {
                    session.apis.forEach((api) => {
                        api.output = output;
                    });
                }
            });
        },
    },
});
// Action creators are generated for each case reducer function
export const sessionActions = sessionsSlice.actions;
export const sessionsReducer = sessionsSlice.reducer;
export const selectCount = (state) => state.sessions.sessions;
const transformEntries = (entries, path = []) => {
    if (!entries)
        return [];
    const list = [];
    for (const key in entries.entries) {
        const item = entries.entries[key];
        const newPath = [...path, key];
        if (item.type === 'Api') {
            list.push({
                title: key,
                description: item.description,
                deprecated: item.deprecated,
                name: key,
                path: newPath,
                input: '',
                output: '',
            });
        }
        else {
            list.push({
                title: key,
                children: transformEntries(item, newPath),
                name: key,
                path: newPath,
                input: '',
                output: '',
            });
        }
    }
    return list;
};
//# sourceMappingURL=sessionsSlice.js.map